@@ -2,11 +2,11 @@ package Graph::SPTHeapElem;
 
 use strict;
 use vars qw($VERSION @ISA);
-use Heap071::Elem;
+use Heap::Elem;
 
-use base 'Heap071::Elem';
+use base 'Heap::Elem';
 
-$VERSION = '0.96_01';
+$VERSION = 0.01;
 
 sub new {
     my $class = shift;
@@ -14,9 +14,7 @@ sub new {
 }
 
 sub cmp {
-    ($_[0]->{ w } || 0) <=> ($_[1]->{ w } || 0) ||
-    ($_[0]->{ u } cmp $_[1]->{ u }) ||
-    ($_[0]->{ u } cmp $_[1]->{ v });
+    ($_[0]->{ w } || 0) <=> ($_[1]->{ w } || 0);
 }
 
 sub val {
